#
# spec file for package python-pysvn
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packagename pysvn
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pysvn
Version:        1.9.22
Release:        1.5
Summary:        Highlevel Subversion Python Bindings
License:        Apache-1.1
Group:          Development/Libraries/Python
URL:            https://pysvn.sourceforge.io/
Source0:        https://sourceforge.net/projects/pysvn/files/pysvn/V%{version}/pysvn-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pycxx-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libapr1-devel
BuildRequires:  libcom_err-devel
BuildRequires:  libcom_err2
BuildRequires:  libexpat-devel
BuildRequires:  neon-devel
BuildRequires:  python-rpm-macros
BuildRequires:  subversion-devel
Requires:       neon
Requires:       subversion
%python_subpackages

%description
pysvn is a set of highlevel Python bindings to Subversion. pysvn
enables tools to be written in Python that use Subversion.

Features:
 * Supports all svn client features
 * Supports svn transaction features required to write svn pre-commit
   hooks
 * Python like interface
 * Documentation and examples provided
 * No need to understand the Subversion C API

%prep
%setup -q -n %{packagename}-%{version}

%{python_expand # python_build and python_install not applicable: not the standard setuptools workflow
# copy pristine dirs to flavor specific directory (shuffled by python_expand)
mkdir -p build
cp -r Builder Docs Examples Kit Patches Source Tests build/
}

rm -r Builder Docs Examples Kit Patches Source Tests
# Remove bundled libs
rm -rf Import

%build
export CFLAGS="%{optflags}"
%{python_expand #
pushd build/Source
$python setup.py configure --enable-debug --verbose --fixed-module-name --norpath

sed -i -e 's@-Wall -fPIC -fexceptions -frtti@%{optflags} -fPIC -frtti@' Makefile
%make_build
popd
}

%install
%{python_expand #
install -d -m 755 %{buildroot}%{$python_sitearch}/%{packagename}
install -p -m 644 build/Source/pysvn/__init__.py %{buildroot}%{$python_sitearch}/%{packagename}
install -p -m 755 build/Source/pysvn/_pysvn.so %{buildroot}%{$python_sitearch}/%{packagename}

mkdir -p pkgdoc-%{$python_bin_suffix}
cp -r build/Docs build/Examples pkgdoc-%{$python_bin_suffix}

%fdupes %{buildroot}%{$python_sitearch}
}

%check
%{python_expand #
pushd build/Tests
# the tests expect a valid answer from locale.getdefaultlocale()
# C.UTF-8 does not work. Use en_US.utf-8.
# The test have not been test in parallel, use one core for now.
export LC_ALL=en_US.UTF-8
PYTHONPATH=%{buildroot}%{$python_sitearch} make -j1
popd
}

%files %{python_files}
%license LICENSE.txt
%doc pkgdoc-%{python_bin_suffix}/Docs pkgdoc-%{python_bin_suffix}/Examples
%{python_sitearch}/%{packagename}

%changelog
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.22:
  * Python 3.12 support
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.20:
  * Python 3.11 support, early enablement for 3.12
  * Add support for subversion 1.14.2
  * Recommend using status2() instead of status()
* Wed May  4 2022 Matej Cepl <mcepl@suse.com>
- Remove skip_python310, it is not needed anymore.
* Wed Feb 16 2022 Dirk Müller <dmueller@suse.com>
- update to 1.9.16:
  * Add support for subversion 1.14.1
  * Use latest openssl 1.1.1k
  * Fix issue with Client.mkdir() on Windows python 3.8 and later
  * No longer able to build python 2.7 kits for Windows.
    An issue with incompatible C++ DLL
- enable python39 build
- disable python310 build (not yet supported)
* Sun May  2 2021 Ben Greiner <code@bnavigator.de>
- Disable python39 build: Need to update pycxx-devel first
- Fix multiflavor build
* Tue Feb 23 2021 andy great <andythe_great@pm.me>
- In reference to pysvn in Fedora package, use manual install
  instead of %%python_install, the pysvn dev recommend to use it.
- Should fix bsc#1182048.
* Sat Feb  6 2021 andy great <andythe_great@pm.me>
- Fix build fail on TW.
* Tue Dec 15 2020 Matej Cepl <mcepl@suse.com>
- Replace %%__python3 with %%python_exec
* Mon Dec 14 2020 andy great <andythe_great@pm.me>
- Adopt spec file from Fedora and enable testing.
* Fri Dec 11 2020 andy great <andythe_great@pm.me>
- Update to version 1.9.12.
  * Binary kits limited to using currently support versions of
    Subversion and Python. However python 2.7 kits will be provided
    after python 2.7 goes end-of-life.
  * Add support for subversion 1.14
  * Build binary kits for Python 3.9b1
  * Add support for gpg-agent auth provider
  * Fix problem building against svn 1.7 which is needed for Centos
    7 support
- Disabled test because errors occured, report at
  https://sourceforge.net/p/pysvn/tickets/8/
- Clean spec file a bit.
- Remove duplicate files with fdupes.
* Thu Aug  9 2018 tchvatal@suse.com
- Update to 1.9.6:
  * No real obvious changelog
  * Support python 3.7
* Thu Sep  7 2017 jengelh@inai.de
- Ensure neutrality of description.
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 1.9.4
- Remove bnc445431_pysvn_svnenv.cpp.diff
  * No longer needed
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Fri Sep 18 2015 astieger@suse.com
- update to 1.8.0:
  * Support python3 sorting of list of PysvnDict objects that name
    a known "key".
  * Support Subversion 1.9.1.
  * Support Python 3.5
  * Fix issue: is_versioned is always 0
  * Fix issue: svn_client_root_url_from_path() would crash if login
    callback was called.
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 1.7.8
  + No changelog available
* Wed Jul 31 2013 hpj@urpla.net
- update to 1.7.7
  * no degestible changelog provided from upstream
* Thu Nov 22 2012 robert.munteanu@gmail.com
- Added patch for bnc#780243, cherry-picked from upstream r1742
* Mon Apr 30 2012 cfarrell@suse.com
- license update: Apache-1.1
  See LICENSE.txt (most of the package is in fact BSD-3-Clause licensed"
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4
* Thu Apr 26 2012 toddrme2178@gmail.com
- Add python 3 package
* Sun Mar  4 2012 coolo@suse.com
- update to 1.7.6:
  * supports subversion 1.7.3 (and earlier)
* Wed Feb  1 2012 saschpe@suse.de
- Ran spec-cleaner
* Mon Oct 31 2011 dmueller@suse.de
- update to 1.7.5:
  * update included pycss to 0.6 to build against subversion 1.7
* Thu Aug 19 2010 toms@suse.de
- Update to version 1.7.4
  * bug fixes for reported issues
* Sat May 29 2010 toms@suse.de
- Update to version 1.7.2
* Sat Jan 23 2010 jengelh@medozas.de
- enable parallel build
* Sat Aug  8 2009 hpj@urpla.net
- update to version 1.7.0
  switch to the authors recommended way to build/install this thing
* Sun Nov 23 2008 coolo@suse.de
- readd the second last change
* Tue Nov 18 2008 toms@suse.de
- Fixed bnc#445431 "undefinied C++ code"
  in pysvn_svnenv.cpp
* Wed Oct 29 2008 ro@suse.de
- fix typo in specfile
- remove doc files from INSTALLED_FILES
* Wed Oct 22 2008 toms@suse.de
- renamed macro _realname
* Thu Sep 25 2008 toms@suse.de
- Taken from home:/termim into factory
* Thu Aug  7 2008 Mikhail Terekhov <termim@gmail.com>
- Version 1.6.0 setup.py
* Wed Feb 28 2007 Jérôme Soyer <saispo@mandriva.org>
- Revision: 130370
- New release
  Bogdano Arendartchuk <bogdano@mandriva.com>
  - fix after version upgrade)
* Tue Dec  5 2006 Jérôme Soyer <saispo@mandriva.org>
- Revision: 91597
- Remove patch and update
- Rebuild for latest pyhton
  + Bogdano Arendartchuk <bogdano@mandriva.com>
  - Import python-pysvn
